ytree\.arbor\.io\.RootFieldIO
=============================

.. currentmodule:: ytree.arbor.io

.. autoclass:: RootFieldIO

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~RootFieldIO.__init__
      ~RootFieldIO.get_fields
   
   

   
   
   